Browbeat Rally Plugin: netcreate-boot
======================================

Functions:
----------
- Create 'N' Neutron network
- Create 'N' Neutron subnet
- Launch Nova instance attached to all the networks created
